<!-- 
source venv/bin/activate

python -m build

twine upload dist/*

pypi-AgEIcHlwaS5vcmcCJGU3ZDlmZDNjLTI0MTUtNDMyOS1iMTE2LWYwZTI0MmQ0MmZmMwACKlszLCI5YjczMWU2MS1mZjg3LTQyNmYtYWZlYy02ZDc1MzNjNThkZmIiXQAABiC1rb82OLVAGE2hOUdzFwaAbYeqxVeArR4Fpu2y053h8A

 -->


# Your Package

A small Python package that says hello.

## Installation

```bash
pip install ezbillpg
